@@ -36,6 +36,12 @@ type Addon struct {
 	// Force overwrites an existing self-managed add-on with an EKS managed add-on.
 	// Force is intended to be used when migrating an existing self-managed add-on to an EKS managed add-on.
 	Force bool `json:"-"`
+	// +optional
+	Publishers []string `json:"publishers,omitempty"`
+	// +optional
+	Types []string `json:"types,omitempty"`
+	// +optional
+	Owners []string `json:"owners,omitempty"`
 }
 
 func (a Addon) CanonicalName() string {
